@@ -105,8 +105,8 @@ PRODUCTS = {
     # are to be sent to Linux drivers resources.
     "libats": '-1',
     "Alazar-Front-Panel": '-2',
-    "Firmware Update Utility (CLI)": '-3',
-    "Firmware Update Utility (GUI)": '-4',
+    "fwupdater-cli": '-3',
+    "fwupdater-gui": '-4',
 }
 
 # Identifies a package that can be registered to the website
@@ -159,13 +159,33 @@ def get_name(packageid):
             return packageid.key + " " + packageid.arch + " driver for Windows"
         elif packageid.os == 'Linux (.deb)' or packageid.os == 'Linux (.rpm)':
             return packageid.key + " " + packageid.arch + " driver for Linux"
+    if packageid.key == 'libats':
+        return "Libats library"
+    if packageid.key == 'fwupdater-cli':
+        return "Firmware Update Utility (CLI)"
+    if packageid.key == 'fwupdater-gui':
+        return "Firmware Update Utility (GUI)"
+    return packageid.key
+
+def get_french_name(packageid):
+    if is_driver(packageid.key):
+        if packageid.os == 'Windows':
+            return "Pilotes " + packageid.key + " " + packageid.arch + " pour Windows"
+        elif packageid.os == 'Linux (.deb)' or packageid.os == 'Linux (.rpm)':
+            return "Pilotes " + packageid.key + " " + packageid.arch + " pour Linux"
+    if packageid.key == 'libats':
+        return "Librairie libats"
+    if packageid.key == 'fwupdater-cli':
+        return "Utilitaire de mise à jour de micrologiciel (CLI)"
+    if packageid.key == 'fwupdater-gui':
+        return "Utilitaire de mise à jour de micrologiciel (GUI)"
     return packageid.key
 
 def get_category(key):
     if is_driver(key):
         return 'driver'
-    elif key == "Firmware Update Utility (CLI)" or \
-         key == "Firmware Update Utility (GUI)":
+    elif key == "fwupdater-cli" or \
+         key == "fwupdater-gui":
         return 'utility'
     else:
         return 'software'
@@ -188,6 +208,7 @@ Package = namedtuple(
         'name',  # type: str
         'arch',  # type: str
         'category',  # type: str
+        'name_french',  # type: str
     ])
 
 
@@ -222,14 +243,15 @@ def packages_from_files(files):
                     readme=readmes[packageid.key],
                     name=get_name(packageid),
                     arch=packageid.arch,
-                    category=get_category(packageid.key)))
+                    category=get_category(packageid.key),
+                    name_french=get_french_name(packageid)))
     return packages
 
 # Packages to be sent to Linux drivers resources.
 def is_linux_resource(package):
     if package.os != 'Linux (.deb)' and package.os != 'Linux (.rpm)':
         return False
-    if package.name == 'libats' or \
+    if package.name == 'Libats library' or \
        package.name == 'Alazar-Front-Panel' or \
        package.name == 'Firmware Update Utility (CLI)' or \
        package.name == 'Firmware Update Utility (GUI)':
@@ -248,7 +270,7 @@ def payload_from_packages(packages, base_url, version, password):
                 if is_driver(key):
                     payload.append({
                         "os": package.os,
-                        "product_id": PRODUCTS[key].product_id,
+                        "product_id": PRODUCTS[key],
                         "url": base_url + package.installer,
                         "release_notes_url": base_url + package.readme,
                         "version": version,
@@ -256,8 +278,9 @@ def payload_from_packages(packages, base_url, version, password):
                         "name": package.name,
                         "arch": package.arch,
                         "category": package.category,
+                        "name_french": package.name_french,
                     })
-        elif package.product_id > 0:
+        if not package.product_id.startswith('-'):
             payload.append({
                 "os": package.os,
                 "product_id": package.product_id,
@@ -268,6 +291,7 @@ def payload_from_packages(packages, base_url, version, password):
                 "name": package.name,
                 "arch": package.arch,
                 "category": package.category,
+                "name_french": package.name_french,
             })
     return json.dumps(payload)
 
