@@ -14,7 +14,8 @@ class TestRegister(unittest.TestCase):
                     readme='ATS-SDK-ReleaseNotes.html',
                     name='ATS-SDK',
                     arch='x86_64',
-                    category='software')
+                    category='software',
+                    name_french='ATS-SDK')
         ])
         packages = packages_from_files(
             ['/path/to/installer/drivers-ats9352-dkms_7.3.1_arm64.deb', '/path/to/installer/ATS9352_Driver_V7.3.1_Readme.html'])
@@ -25,27 +26,30 @@ class TestRegister(unittest.TestCase):
                     readme='ATS9352_Driver_V7.3.1_Readme.html',
                     name='ATS9352 arm64 driver for Linux',
                     arch='arm64',
-                    category='driver')
+                    category='driver',
+                    name_french='Pilotes ATS9352 arm64 pour Linux')
         ])
         package = Package(os='Linux (.deb)',
                         product_id='-1',
                         installer='',
                         readme='',
-                        name='libats',
+                        name='Libats library',
                         arch='x86_64',
-                        category='')
+                        category='',
+                        name_french='')
         self.assertEqual(is_linux_resource(package), 1)
         package = Package(os='Windows',
                         product_id='',
                         installer='',
                         readme='',
-                        name='libats',
+                        name='Libats library',
                         arch='',
-                        category='')
+                        category='',
+                        name_french='')
         self.assertEqual(is_linux_resource(package), 0)
         self.assertEqual(get_category('ATS9352'), 'driver')
         self.assertEqual(get_category('libats'), 'software')
-        self.assertEqual(get_category('Firmware Update Utility (CLI)'), 'utility')
+        self.assertEqual(get_category('fwupdater-cli'), 'utility')
         
 
 
